import java.sql.*;
import javax.sql.*;
import java.util.*;
import javax.ejb.*;
import javax.naming.*;
import javax.rmi.PortableRemoteObject;

public class PocketMoneyBean implements EntityBean {
	protected String owner;
	protected int remaining;

	private String dbName = "java:comp/env/jdbc/PocketMoneyDB";
	private String ejbPocketMoneyLine = "java:comp/env/ejb/PocketMoneyLine";
	private EntityContext context;

	public String getOwner() {
		return owner;
	}

	public void setOwner(String owner) {
		this.owner = owner;
	}

	public int getRemaining() {
		return remaining;
	}

	public void setRemaining(int remaining) {
		this.remaining = remaining;
	}

	public PocketMoneyVO getVO() {
		return new PocketMoneyVO(getOwner(), getRemaining());
	}

	public Collection getLines() {
		try {
			return getPocketMoneyLineHome().findAll(owner);
		} catch (Exception ex) {
			throw new EJBException("getLines: " + ex.getMessage());
		}
	}

	public void setEntityContext(EntityContext context) {
		this.context = context;
	}

	public void unsetEntityContext() {
		this.context = null;
	}

	public void ejbActivate() {}

	public void ejbPassivate() {}

	public String ejbCreate(String owner, int remaining) throws CreateException {
		Connection co = null;
		PreparedStatement st = null;
		System.out.print("PocketMoneyBean.ejbCreate()...");
		try {
			co = this.getConnection();
			st = co.prepareStatement("insert into pm values(?, ?)");
			st.setString(1, owner);
			st.setInt(2, remaining);
			st.executeUpdate();
		} catch (Exception ex) {
			throw new EJBException("ejbCreate: " + ex.getMessage());
		} finally {
			try {st.close();} catch (Exception ex) {}
			try {co.close();} catch (Exception ex) {}
		}
		this.owner = owner;
		this.remaining = remaining;
		System.out.println("done");
		return owner;
	}

	public void ejbPostCreate(String owner, int remaining) {}

	public void ejbRemove() {
		Connection co = null;
		PreparedStatement st = null;
		System.out.print("PocketMoneyBean.ejbRemove()...");
		try {
			co = this.getConnection();
			st = co.prepareStatement("delete from pm where owner = ?");
			st.setString(1, owner);
			st.executeUpdate();
		} catch (Exception ex) {
			throw new EJBException("ejbRemove: " + ex.getMessage());
		} finally {
			try {st.close();} catch (Exception ex) {}
			try {co.close();} catch (Exception ex) {}
		}
		System.out.println("done");
	}

	public void ejbLoad() {
		Connection co = null;
		PreparedStatement st = null;
		ResultSet rs = null;
		System.out.print("PocketMoneyBean.ejbLoad()...");
		boolean result = false;
		try {
			String pk = (String)context.getPrimaryKey();
			co = this.getConnection();
			st = co.prepareStatement("select * from pm where owner = ?");
			st.setString(1, pk);
			rs = st.executeQuery();
			if (result = rs.next()) {
				owner = rs.getString(1);
				remaining = rs.getInt(2);
			}
		} catch (Exception ex) {
			throw new EJBException("ejbLoad: " + ex.getMessage());
		} finally {
			try {rs.close();} catch (Exception ex) {}
			try {st.close();} catch (Exception ex) {}
			try {co.close();} catch (Exception ex) {}
		}
		if (!result) {
			throw new NoSuchEntityException("Row for " + owner + " is not found.");
		}
		System.out.println("done");
	}

	public void ejbStore() {
		Connection co = null;
		PreparedStatement st = null;
		System.out.print("PocketMoneyBean.ejbStore()...");
		try {
			co = this.getConnection();
			st = co.prepareStatement("update pm set remaining = ? where owner = ?");
			st.setInt(1, remaining);
			st.setString(2, owner);
			st.executeUpdate();
		} catch (Exception ex) {
			throw new EJBException("ejbStore: " + ex.getMessage());
		} finally {
			try {st.close();} catch (Exception ex) {}
			try {co.close();} catch (Exception ex) {}
		}
		System.out.println("done");
	}

	public String ejbFindByPrimaryKey(String owner) throws FinderException {
		Connection co = null;
		PreparedStatement st = null;
		ResultSet rs = null;
		System.out.print("PocketMoneyBean.ejbFindByPrimaryKey()...");
		boolean result;
		try {
			co = this.getConnection();
			st = co.prepareStatement("select owner from pm where owner = ?");
			st.setString(1, owner);
			rs = st.executeQuery();
			result = rs.next();
		} catch (Exception ex) {
			throw new EJBException("ejbFindByPrimaryKey: " + ex.getMessage());
		} finally {
			try {rs.close();} catch (Exception ex) {}
			try {st.close();} catch (Exception ex) {}
			try {co.close();} catch (Exception ex) {}
		}
		if (!result) {
			throw new ObjectNotFoundException("Row for " + owner + " is not found.");
		}
		System.out.println("done");
		return owner;
	}

	public void deposit(int amount, String reason) {
		try {
			remaining += amount;
			getPocketMoneyLineHome().create(owner, new Timestamp(System.currentTimeMillis()), amount, reason);
		} catch (Exception ex) {
			ex.printStackTrace();
			throw new EJBException(ex);
		}
	}

	public void payment(int amount, String reason) {
		this.deposit(- amount, reason);
	}

	private Connection getConnection() throws NamingException, SQLException {
		try {
			InitialContext ic = new InitialContext();
			DataSource ds = (DataSource)ic.lookup(dbName);
			Connection co = ds.getConnection();
			ic.close();
			return co;
		} catch (NamingException ex) {
			throw new RuntimeException(ex.getMessage());
		}
	}

	protected PocketMoneyLineHome getPocketMoneyLineHome() {
		try {
			InitialContext ic = new InitialContext();
			Object objref = ic.lookup(ejbPocketMoneyLine);
			PocketMoneyLineHome home = (PocketMoneyLineHome)PortableRemoteObject.narrow(objref, PocketMoneyLineHome.class);
			ic.close();
			return home;
		} catch (NamingException ex) {
			throw new RuntimeException(ex.getMessage());
		}
	}
}
