import java.sql.*;
import javax.sql.*;
import java.util.*;
import javax.ejb.*;
import javax.naming.*;

public class PocketMoneyLineBean implements EntityBean {
	protected String owner;
	protected Timestamp timestamp;
	protected int balance;
	protected String reason;

	private String dbName = "java:comp/env/jdbc/PocketMoneyDB";
	private EntityContext context;

	public String getOwner() {
		return owner;
	}

	public void setOwner(String owner) {
		this.owner = owner;
	}

	public Timestamp getTimestamp() {
		return timestamp;
	}

	public void setTimestamp(Timestamp timestamp) {
		this.timestamp = timestamp;
	}

	public int getBalance() {
		return balance;
	}

	public void setBalance(int balance) {
		this.balance = balance;
	}

	public String getReason() {
		return reason;
	}

	public void setReason(String reason) {
		this.reason = reason;
	}

	public PocketMoneyLineVO getVO() {
		return new PocketMoneyLineVO(getOwner(), getTimestamp(), getBalance(), getReason());
	}

	public void setEntityContext(EntityContext context) {
		this.context = context;
	}

	public void unsetEntityContext() {
		this.context = null;
	}

	public void ejbActivate() {}

	public void ejbPassivate() {}

	public PocketMoneyLinePK ejbCreate(String owner, Timestamp timestamp, int balance, String reason) throws CreateException {
		Connection co = null;
		PreparedStatement st = null;
		System.out.print("PocketMoneyLineBean.ejbCreate()...");
		try {
			co = this.getConnection();
			st = co.prepareStatement("insert into pmline values(?, ?, ?, ?)");
			st.setString(1, owner);
			st.setTimestamp(2, new Timestamp(timestamp.getTime()));
			st.setInt(3, balance);
			st.setString(4, reason);
			st.executeUpdate();
		} catch (Exception ex) {
			throw new EJBException("ejbCreate: " + ex.getMessage());
		} finally {
			try {st.close();} catch (Exception ex) {}
			try {co.close();} catch (Exception ex) {}
		}
		this.owner = owner;
		this.timestamp = timestamp;
		this.balance = balance;
		this.reason = reason;
		System.out.println("done");
		return new PocketMoneyLinePK(owner, timestamp);
	}

	public void ejbPostCreate(String owner, Timestamp timestamp, int balance, String reason) {}

	public void ejbRemove() {
		Connection co = null;
		PreparedStatement st = null;
		System.out.print("PocketMoneyLineBean.ejbRemove()...");
		try {
			co = this.getConnection();
			st = co.prepareStatement("delete from pmline where owner = ? and time_stamp = ?");
			st.setString(1, owner);
			st.setTimestamp(2, new Timestamp(timestamp.getTime()));
			st.executeUpdate();
		} catch (Exception ex) {
			throw new EJBException("ejbRemove: " + ex.getMessage());
		} finally {
			try {st.close();} catch (Exception ex) {}
			try {co.close();} catch (Exception ex) {}
		}
		System.out.println("done");
	}

	public void ejbLoad() {
		Connection co = null;
		PreparedStatement st = null;
		ResultSet rs = null;
		System.out.print("PocketMoneyLineBean.ejbLoad()...");
		boolean result = false;
		try {
			PocketMoneyLinePK pk = (PocketMoneyLinePK)context.getPrimaryKey();
			co = this.getConnection();
			st = co.prepareStatement("select * from pmline where owner = ? and time_stamp = ?");
System.out.println("pk = " + pk.owner + " " + pk.timestamp);
			st.setString(1, pk.owner);
			st.setTimestamp(2, (Timestamp)pk.timestamp);
			rs = st.executeQuery();
			if (result = rs.next()) {
System.out.println("iftrue");
				owner = rs.getString(1);
				timestamp = rs.getTimestamp(2);
				balance = rs.getInt(3);
				reason = rs.getString(4);
			}
System.out.println("endif");
		} catch (Exception ex) {
			ex.printStackTrace();
			throw new EJBException("ejbLoad: " + ex.getMessage());
		} finally {
			try {rs.close();} catch (Exception ex) {}
			try {st.close();} catch (Exception ex) {}
			try {co.close();} catch (Exception ex) {}
		}
		if (!result) {
			throw new NoSuchEntityException("Row for " + owner + " is not found.");
		}
		System.out.println("done");
	}

	public void ejbStore() {
		Connection co = null;
		PreparedStatement st = null;
		System.out.print("PocketMoneyLineBean.ejbStore()...");
		try {
			co = this.getConnection();
			st = co.prepareStatement("update pmline set balance = ?, reason = ? where owner = ? and time_stamp = ?");
			st.setInt(1, balance);
			st.setString(2, reason);
			st.setString(3, owner);
			st.setTimestamp(4, new Timestamp(timestamp.getTime()));
			st.executeUpdate();
		} catch (Exception ex) {
			throw new EJBException("ejbStore: " + ex.getMessage());
		} finally {
			try {st.close();} catch (Exception ex) {}
			try {co.close();} catch (Exception ex) {}
		}
		System.out.println("done");
	}

	public PocketMoneyLinePK ejbFindByPrimaryKey(PocketMoneyLinePK pk) throws FinderException {
		Connection co = null;
		PreparedStatement st = null;
		ResultSet rs = null;
		System.out.print("PocketMoneyLineBean.ejbFindByPrimaryKey()...");
		boolean result;
		try {
			co = this.getConnection();
			st = co.prepareStatement("select owner from pmline where owner = ? and time_stamp = ?");
			st.setString(1, pk.owner);
			st.setTimestamp(2, (Timestamp)pk.timestamp);
			rs = st.executeQuery();
			result = rs.next();
		} catch (Exception ex) {
			throw new EJBException("ejbFindByPrimaryKey: " + ex.getMessage());
		} finally {
			try {rs.close();} catch (Exception ex) {}
			try {st.close();} catch (Exception ex) {}
			try {co.close();} catch (Exception ex) {}
		}
		if (!result) {
			throw new ObjectNotFoundException("Row for " + owner + " is not found.");
		}
		System.out.println("done");
		return pk;
	}

	public Collection ejbFindAll(String owner) throws FinderException {
		Connection co = null;
		PreparedStatement st = null;
		ResultSet rs = null;
		System.out.print("PocketMoneyLineBean.ejbFindAll()...");
		Vector result = new Vector();
		try {
			co = this.getConnection();
			st = co.prepareStatement("select owner, time_stamp from pmline where owner = ?");
			st.setString(1, owner);
			rs = st.executeQuery();
			while (rs.next()) {
				result.addElement(new PocketMoneyLinePK(rs.getString(1), rs.getTimestamp(2)));
			}
		} catch (Exception ex) {
			throw new EJBException("ejbFindByPrimaryKey: " + ex.getMessage());
		} finally {
			try {rs.close();} catch (Exception ex) {}
			try {st.close();} catch (Exception ex) {}
			try {co.close();} catch (Exception ex) {}
		}
		System.out.println("done");
		return result;
	}

	private Connection getConnection() throws NamingException, SQLException {
		InitialContext ic = new InitialContext();
		DataSource ds = (DataSource)ic.lookup(dbName);
		Connection co = ds.getConnection();
		ic.close();
		return co;
	}
}
